WalkClosure

Type Alias WalkClosure 

pub type WalkClosure<'a> = dyn FnMut(&Value, &Value, &Value, &[String]) -> Value + 'a;
WalkApply(key, val, parent, path) -> any. key is Noval at the root and a Str for every descendant (matches the canonical, where items always yields string keys).